@@ -94,10 +94,10 @@ class LDLite:
     def connect_db(self, filename=None):
         """Connects to an embedded database for storing data.
 
-        The optional *filename* is a local file containing the DuckDB database
-        or where the database will be created if it does not exist.  If
-        *filename* is not specified, the database will be stored in memory and
-        will not be persisted to disk.
+        The optional *filename* designates a local file containing the DuckDB
+        database or where the database will be created if it does not exist.
+        If *filename* is not specified, the database will be stored in memory
+        and will not be persisted to disk.
 
         This function returns a connection to the database which can be used to
         submit SQL queries.
